# Copyright (c) 2022 Boston Dynamics, Inc.  All rights reserved.
#
# Downloading, reproducing, distributing or otherwise using the SDK Software
# is subject to the terms and conditions of the Boston Dynamics Software
# Development Kit License (20191101-BDSDK-SL).

"""Code for reading and writing 'bddf' data files."""

# Importing symbols to use directly via "bosdyn.bddf" namespace.

# pylint: disable=unused-import
from .common import (AddSeriesError, ChecksumError, DataError, DataFormatError, LOGGER,
                     PROTOBUF_CONTENT_TYPE, ParseError, SeriesNotUniqueError)

# Class for reading data from a file-like object which is seekable.
from .data_reader import DataReader

# Class for writing data to a file.
from .data_writer import DataWriter

# Class for registering a series which stores GRPC request/response pairs.
from .grpc_reader import GrpcReader

# Class for registering a series which stores GRPC request/response pairs.
from .grpc_service_writer import GrpcServiceWriter

# A class for reading message data from a DataFile.
from .message_reader import MessageReader

# Class for reading a series of POD data from a DataFile.
from .pod_series_reader import PodSeriesReader

# Class which assists with writing POD data values into a series, within a DataWriter.
from .pod_series_writer import PodSeriesWriter

# Class which assists with writing POD data values into a series, within a DataWriter.
from .protobuf_series_writer import ProtobufSeriesWriter

# A class for reading a single channel of Protobuf data from a DataFile.
from .protobuf_channel_reader import ProtobufChannelReader

# A class for reading Protobuf data from a DataFile.
from .protobuf_reader import ProtobufReader

# A data reader which reads the file format from a stream, without seeking.
from .stream_data_reader import StreamDataReader
